==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_external/l10n/ka.js <==
OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Grant access",
    "Error configuring OAuth1" : "Error configuring OAuth1",
    "Please provide a valid app key and secret." : "Please provide a valid app key and secret.",
    "Error configuring OAuth2" : "Error configuring OAuth2",
    "Generate keys" : "Generate keys",
    "Error generating key pair" : "Error generating key pair",
    "Forbidden to manage local mounts" : "Forbidden to manage local mounts",
    "Storage with ID \"%d\" not found" : "Storage with ID \"%d\" not found",
    "Invalid backend or authentication mechanism class" : "Invalid backend or authentication mechanism class",
    "Invalid mount point" : "Invalid mount point",
    "Objectstore forbidden" : "Objectstore forbidden",
    "Invalid storage backend \"%s\"" : "Invalid storage backend \"%s\"",
    "Not permitted to use backend \"%s\"" : "Not permitted to use backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Not permitted to use authentication mechanism \"%s\"",
    "Unsatisfied backend parameters" : "Unsatisfied backend parameters",
    "Unsatisfied authentication mechanism parameters" : "Unsatisfied authentication mechanism parameters",
    "Insufficient data: %s" : "Insufficient data: %s",
    "%s" : "%s",
    "Access key" : "Access key",
    "Secret key" : "Secret key",
    "Builtin" : "Builtin",
    "None" : "None",
    "OAuth1" : "OAuth1",
    "App key" : "App key",
    "App secret" : "App secret",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client ID",
    "Client secret" : "Client secret",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Login",
    "Password" : "პაროლი",
    "Tenant name" : "Tenant name",
    "Identity endpoint URL" : "Identity endpoint URL",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domain",
    "Rackspace" : "Rackspace",
    "API key" : "API key",
    "Global credentials" : "Global credentials",
    "Log-in credentials, save in database" : "Log-in credentials, save in database",
    "Log-in credentials, save in session" : "Log-in credentials, save in session",
    "RSA public key" : "RSA public key",
    "Public key" : "Public key",
    "RSA private key" : "RSA private key",
    "Private key" : "Private key",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Kerberos default realm, defaults to \"WORKGROUP\"",
    "Kerberos ticket Apache mode" : "Kerberos ticket Apache mode",
    "Kerberos ticket" : "Kerberos ticket",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Bucket",
    "Hostname" : "Hostname",
    "Port" : "Port",
    "Region" : "Region",
    "Storage Class" : "Storage Class",
    "Enable SSL" : "Enable SSL",
    "Enable Path Style" : "Enable Path Style",
    "Legacy (v2) authentication" : "Legacy (v2) authentication",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Remote subfolder",
    "Secure https://" : "Secure https://",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Secure ftps://",
    "Local" : "Local",
    "Location" : "Location",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP with secret key login",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "Share",
    "Show hidden files" : "Show hidden files",
    "Case sensitive file system" : "Case sensitive file system",
    "Disabling it will allow to use a case insensitive file system, but comes with a performance penalty" : "Disabling it will allow to use a case insensitive file system, but comes with a performance penalty",
    "Verify ACL access when listing files" : "Verify ACL access when listing files",
    "Timeout" : "Timeout",
    "SMB/CIFS using OC login" : "SMB/CIFS using OC login",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Service name",
    "Request timeout (seconds)" : "Request timeout (seconds)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it.",
    "External storage" : "External storage",
    "External storage support" : "External storage support",
    "Adds basic external storage support" : "Adds basic external storage support",
    "Confirm" : "Confirm",
    "Unable to update this external storage config. {statusMessage}" : "Unable to update this external storage config. {statusMessage}",
    "New configuration successfully saved" : "New configuration successfully saved",
    "Enter missing credentials" : "Enter missing credentials",
    "There was an error with this external storage." : "There was an error with this external storage.",
    "We were unable to check the external storage {basename}" : "We were unable to check the external storage {basename}",
    "Examine this faulty external storage configuration" : "Examine this faulty external storage configuration",
    "Open in Files" : "Open in Files",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "There was an error with this external storage. Do you want to review this mount point config in the settings page?",
    "External mount error" : "External mount error",
    "List of external storage." : "List of external storage.",
    "There is no external storage configured. You can configure them in your Personal settings." : "There is no external storage configured. You can configure them in your Personal settings.",
    "There is no external storage configured and you don't have the permission to configure them." : "There is no external storage configured and you don't have the permission to configure them.",
    "No external storage" : "No external storage",
    "Storage type" : "Storage type",
    "Unknown" : "Unknown",
    "Scope" : "Scope",
    "Personal" : "Personal",
    "System" : "System",
    "(Group)" : "(Group)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibility with Mac NFD encoding (slow)",
    "Enable encryption" : "Enable encryption",
    "Enable previews" : "Enable previews",
    "Enable sharing" : "Enable sharing",
    "Check for changes" : "Check for changes",
    "Never" : "Never",
    "Once every direct access" : "Once every direct access",
    "Read only" : "Read only",
    "Disconnect" : "Disconnect",
    "Admin defined" : "Admin defined",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "Automatic status checking is disabled due to the large number of configured storages, click to check status",
    "Are you sure you want to disconnect this external storage? It will make the storage unavailable in Nextcloud and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "Are you sure you want to disconnect this external storage? It will make the storage unavailable in Nextcloud and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself.",
    "Delete storage?" : "Delete storage?",
    "Click to recheck the configuration" : "Click to recheck the configuration",
    "Saved" : "Saved",
    "Saving …" : "Saving …",
    "Save" : "Save",
    "No external storage configured or you don't have the permission to configure them" : "No external storage configured or you don't have the permission to configure them",
    "Open documentation" : "Open documentation",
    "Folder name" : "Folder name",
    "Authentication" : "Authentication",
    "Configuration" : "Configuration",
    "Available for" : "Available for",
    "Add storage" : "Add storage",
    "Advanced settings" : "Advanced settings",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Global credentials can be used to authenticate with multiple external storages that have the same credentials."
},
"nplurals=2; plural=(n!=1);");

==> nextcloud-32.0.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/files_external/l10n/ka.js <==
OC.L10N.register(
    "files_external",
    {
    "Grant access" : "Grant access",
    "Error configuring OAuth2" : "Error configuring OAuth2",
    "Generate keys" : "Generate keys",
    "Error generating key pair" : "Error generating key pair",
    "Forbidden to manage local mounts" : "Forbidden to manage local mounts",
    "Storage with ID \"%d\" not found" : "Storage with ID \"%d\" not found",
    "Invalid backend or authentication mechanism class" : "Invalid backend or authentication mechanism class",
    "Invalid mount point" : "Invalid mount point",
    "Objectstore forbidden" : "Objectstore forbidden",
    "Invalid storage backend \"%s\"" : "Invalid storage backend \"%s\"",
    "Not permitted to use backend \"%s\"" : "Not permitted to use backend \"%s\"",
    "Not permitted to use authentication mechanism \"%s\"" : "Not permitted to use authentication mechanism \"%s\"",
    "Unsatisfied backend parameters" : "Unsatisfied backend parameters",
    "Unsatisfied authentication mechanism parameters" : "Unsatisfied authentication mechanism parameters",
    "Insufficient data: %s" : "Insufficient data: %s",
    "%s" : "%s",
    "Access key" : "Access key",
    "Secret key" : "Secret key",
    "Builtin" : "Builtin",
    "None" : "None",
    "OAuth2" : "OAuth2",
    "Client ID" : "Client ID",
    "Client secret" : "Client secret",
    "OpenStack v2" : "OpenStack v2",
    "Login" : "Login",
    "Password" : "პაროლი",
    "Tenant name" : "Tenant name",
    "Identity endpoint URL" : "Identity endpoint URL",
    "OpenStack v3" : "OpenStack v3",
    "Domain" : "Domain",
    "Rackspace" : "Rackspace",
    "API key" : "API key",
    "Global credentials" : "Global credentials",
    "Log-in credentials, save in database" : "Log-in credentials, save in database",
    "Log-in credentials, save in session" : "Log-in credentials, save in session",
    "RSA public key" : "RSA public key",
    "Public key" : "Public key",
    "RSA private key" : "RSA private key",
    "Private key" : "Private key",
    "Kerberos default realm, defaults to \"WORKGROUP\"" : "Kerberos default realm, defaults to \"WORKGROUP\"",
    "Kerberos ticket Apache mode" : "Kerberos ticket Apache mode",
    "Kerberos ticket" : "Kerberos ticket",
    "Bucket" : "Bucket",
    "Hostname" : "Hostname",
    "Port" : "Port",
    "Region" : "Region",
    "Storage Class" : "Storage Class",
    "Enable SSL" : "Enable SSL",
    "Enable Path Style" : "Enable Path Style",
    "Legacy (v2) authentication" : "Legacy (v2) authentication",
    "WebDAV" : "WebDAV",
    "URL" : "URL",
    "Remote subfolder" : "Remote subfolder",
    "Secure https://" : "Secure https://",
    "FTP" : "FTP",
    "Host" : "Host",
    "Secure ftps://" : "Secure ftps://",
    "Local" : "Local",
    "Location" : "Location",
    "Nextcloud" : "Nextcloud",
    "SFTP" : "SFTP",
    "Root" : "Root",
    "SFTP with secret key login" : "SFTP with secret key login",
    "SMB/CIFS" : "SMB/CIFS",
    "Share" : "Share",
    "Show hidden files" : "Show hidden files",
    "Case sensitive file system" : "Case sensitive file system",
    "Disabling it will allow to use a case insensitive file system, but comes with a performance penalty" : "Disabling it will allow to use a case insensitive file system, but comes with a performance penalty",
    "Verify ACL access when listing files" : "Verify ACL access when listing files",
    "Timeout" : "Timeout",
    "SMB/CIFS using OC login" : "SMB/CIFS using OC login",
    "OpenStack Object Storage" : "OpenStack Object Storage",
    "Service name" : "Service name",
    "Request timeout (seconds)" : "Request timeout (seconds)",
    "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it.",
    "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it.",
    "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it." : "\"%1$s\" is not installed. Mounting of %2$s is not possible. Please ask your system administrator to install it.",
    "External storage" : "External storage",
    "External storage support" : "External storage support",
    "Adds basic external storage support" : "Adds basic external storage support",
    "Confirm" : "Confirm",
    "Unable to update this external storage config. {statusMessage}" : "Unable to update this external storage config. {statusMessage}",
    "New configuration successfully saved" : "New configuration successfully saved",
    "Enter missing credentials" : "Enter missing credentials",
    "There was an error with this external storage." : "There was an error with this external storage.",
    "We were unable to check the external storage {basename}" : "We were unable to check the external storage {basename}",
    "Examine this faulty external storage configuration" : "Examine this faulty external storage configuration",
    "Open in Files" : "Open in Files",
    "There was an error with this external storage. Do you want to review this mount point config in the settings page?" : "There was an error with this external storage. Do you want to review this mount point config in the settings page?",
    "External mount error" : "External mount error",
    "List of external storage." : "List of external storage.",
    "There is no external storage configured. You can configure them in your Personal settings." : "There is no external storage configured. You can configure them in your Personal settings.",
    "There is no external storage configured and you don't have the permission to configure them." : "There is no external storage configured and you don't have the permission to configure them.",
    "No external storage" : "No external storage",
    "Storage type" : "Storage type",
    "Unknown" : "Unknown",
    "Scope" : "Scope",
    "Personal" : "Personal",
    "System" : "System",
    "(Group)" : "(Group)",
    "Compatibility with Mac NFD encoding (slow)" : "Compatibility with Mac NFD encoding (slow)",
    "Enable encryption" : "Enable encryption",
    "Enable previews" : "Enable previews",
    "Enable sharing" : "Enable sharing",
    "Check for changes" : "Check for changes",
    "Never" : "Never",
    "Once every direct access" : "Once every direct access",
    "Read only" : "Read only",
    "Disconnect" : "Disconnect",
    "Admin defined" : "Admin defined",
    "Automatic status checking is disabled due to the large number of configured storages, click to check status" : "Automatic status checking is disabled due to the large number of configured storages, click to check status",
    "Delete storage?" : "Delete storage?",
    "Click to recheck the configuration" : "Click to recheck the configuration",
    "Saved" : "Saved",
    "Saving …" : "Saving …",
    "Save" : "Save",
    "No external storage configured or you don't have the permission to configure them" : "No external storage configured or you don't have the permission to configure them",
    "Open documentation" : "Open documentation",
    "Folder name" : "Folder name",
    "Authentication" : "Authentication",
    "Configuration" : "Configuration",
    "Available for" : "Available for",
    "Add storage" : "Add storage",
    "Advanced settings" : "Advanced settings",
    "Global credentials can be used to authenticate with multiple external storages that have the same credentials." : "Global credentials can be used to authenticate with multiple external storages that have the same credentials.",
    "Error configuring OAuth1" : "Error configuring OAuth1",
    "Please provide a valid app key and secret." : "Please provide a valid app key and secret.",
    "OAuth1" : "OAuth1",
    "App key" : "App key",
    "App secret" : "App secret",
    "Are you sure you want to disconnect this external storage? It will make the storage unavailable in Nextcloud and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself." : "Are you sure you want to disconnect this external storage? It will make the storage unavailable in Nextcloud and will lead to a deletion of these files and folders on any sync client that is currently connected but will not delete any files and folders on the external storage itself.",
    "Saving …" : "Saving …"
},
"nplurals=2; plural=(n!=1);");
